@@ -45,6 +45,12 @@ class PostgresDialect(Dialect):
             'schema': 'public'
         }
 
+    def get_warehouse_name_and_schema(self) -> dict:
+        return {
+            'database_name': self.database,
+            'database_schema': self.schema
+        }
+
     def safe_connection_data(self):
         return [
             self.type,
@@ -121,7 +127,7 @@ class PostgresDialect(Dialect):
             return f'"{self.schema}"."{table_name}"'
         return f'"{table_name}"'
 
-    def qualify_column_name(self, column_name: str):
+    def qualify_column_name(self, column_name: str, source_type: str = None):
         return f'"{column_name}"'
 
     def sql_expr_regexp_like(self, expr: str, pattern: str):
